GpsTimePluginPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- GpsTimePluginPlatform
- Implementers
Constructors
- GpsTimePluginPlatform()
- Constructs a GpsTimePluginPlatform.
Properties
-
gpsTimeStream
→ Stream<
Map> -
Stream of raw GPS time data maps from the native platform.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startListening(
) → Future< void> - Starts GPS location updates on the native side.
-
stopListening(
) → Future< void> - Stops GPS location updates on the native side.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ GpsTimePluginPlatform
-
The default instance of GpsTimePluginPlatform to use.
getter/setter pair